@@ -20,8 +20,6 @@
 
 #include "test.h"
 
-#include "KDBusConnectionPool"
-
 #include <agentinstancecreatejob.h>
 #include <collectiondeletejob.h>
 #include <collectionfetchjob.h>
@@ -29,6 +27,7 @@
 
 #include <QDebug>
 #include <QTest>
+#include <QDBusConnection>
 #include <QDBusInterface>
 
 using namespace Akonadi;
@@ -62,7 +61,7 @@ void MakeTest::createAgent(const QString &name)
 void MakeTest::configureDBusIface(const QString &name, const QString &dir)
 {
     QDBusInterface *configIface = new QDBusInterface(QLatin1String("org.freedesktop.Akonadi.Resource.") + currentInstance.identifier(),
-                                                     QStringLiteral("/Settings"), QLatin1String("org.kde.Akonadi.") + name + QLatin1String(".Settings"), KDBusConnectionPool::threadConnection(), this);
+                                                     QStringLiteral("/Settings"), QLatin1String("org.kde.Akonadi.") + name + QLatin1String(".Settings"), QDBusConnection::sessionBus(), this);
 
     configIface->call(QStringLiteral("setPath"), dir);
     configIface->call(QStringLiteral("setReadOnly"), true);
